tsseg.algorithms.kcpd package
=============================

Operates in RKHS with MMD between segments. Supports RBF, linear and cosine kernels.

| **Type:** change point detection
| **Supervision:** semi-supervised or unsupervised

**Implementation:** Vendored from ruptures v1.1.8. BSD 2-Clause.

**Reference:** Arlot, Celisse & Harchaoui (2019), JMLR.

Submodules
----------

tsseg.algorithms.kcpd.kernelcpd module
--------------------------------------

.. automodule:: tsseg.algorithms.kcpd.kernelcpd
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.kcpd
   :members:
   :show-inheritance:
   :undoc-members:
